==> devextreme-22.1.1-alpha-22018-0314.tgz: package/cjs/renovation/ui/scroll_view/common/native_strategy_props.js <==
/**
 * DevExtreme (cjs/renovation/ui/scroll_view/common/native_strategy_props.js)
 * Version: 22.1.0 (build 22018-0314)
 * Build date: Tue Jan 18 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.ScrollableNativeProps = void 0;
var _base_scrollable_props = require("./base_scrollable_props");
var _get_default_option_value = require("../utils/get_default_option_value");

function _extends() {
    _extends = Object.assign || function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}
var ScrollableNativeProps = Object.create(Object.prototype, _extends(Object.getOwnPropertyDescriptors(_base_scrollable_props.BaseScrollableProps), Object.getOwnPropertyDescriptors(Object.defineProperties({
    showScrollbar: "onScroll"
}, {
    useSimulatedScrollbar: {
        get: function() {
            return (0, _get_default_option_value.getDefaultUseSimulatedScrollbar)()
        },
        configurable: true,
        enumerable: true
    },
    refreshStrategy: {
        get: function() {
            return (0, _get_default_option_value.getDefaultNativeRefreshStrategy)()
        },
        configurable: true,
        enumerable: true
    }
}))));
exports.ScrollableNativeProps = ScrollableNativeProps;

==> devextreme-22.2.1-alpha-22245-0308.tgz: package/cjs/renovation/ui/scroll_view/common/native_strategy_props.js <==
/**
 * DevExtreme (cjs/renovation/ui/scroll_view/common/native_strategy_props.js)
 * Version: 22.2.0 (build 22245-0308)
 * Build date: Fri Sep 02 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.ScrollableNativeProps = void 0;
var _base_scrollable_props = require("./base_scrollable_props");
var _get_default_option_value = require("../utils/get_default_option_value");

function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}
var ScrollableNativeProps = Object.create(Object.prototype, _extends(Object.getOwnPropertyDescriptors(_base_scrollable_props.BaseScrollableProps), Object.getOwnPropertyDescriptors(Object.defineProperties({
    showScrollbar: "onScroll"
}, {
    useSimulatedScrollbar: {
        get: function() {
            return (0, _get_default_option_value.getDefaultUseSimulatedScrollbar)()
        },
        configurable: true,
        enumerable: true
    },
    refreshStrategy: {
        get: function() {
            return (0, _get_default_option_value.getDefaultNativeRefreshStrategy)()
        },
        configurable: true,
        enumerable: true
    }
}))));
exports.ScrollableNativeProps = ScrollableNativeProps;
